@@ -4,56 +4,6 @@
 #
 # -----------------------------------
 
-# GlobalChemExtensions Import
-
-# Entities
-
-from global_chem_extensions.entities.molecule.molecule import GlobalChemMolecule
-from global_chem_extensions.entities.protein.protein import GlobalChemProtein
-from global_chem_extensions.entities.rna.rna import GlobalChemRNA
-from global_chem_extensions.entities.dna.dna import GlobalChemDNA
-
-# Visualization
-
-from global_chem_extensions.analysis_tools.sunburster.sunburster import Sunburster
-from global_chem_extensions.analysis_tools.deep_layer_scatter.deep_layer_scatter import DeepLayerScatter
-
-# Analytics
-
-from global_chem_extensions.analysis_tools.smarts_pattern_identifier.smarts_pattern_identifier import SmartsPatternIdentifier
-from global_chem_extensions.analysis_tools.drug_design_filters.drug_design_filters import DrugDesignFilters
-from global_chem_extensions.analysis_tools.node_pca_analysis.node_pca_analysis import PCAAnalysis
-
-# Software Adapters
-
-from global_chem_extensions.software_adapters.pdf_adapter.molpdf_parser import MolPDFAdapter
-from global_chem_extensions.software_adapters.networkx_adapter.networkx_adapter import NetworkxAdapter
-from global_chem_extensions.software_adapters.smarts_visualizer.smarts_visualizer import SmartsVisualizer
-from global_chem_extensions.software_adapters.dimorphite_dl_adapter.dimorphite_dl import DimorphiteAdapter
-
-# Language Adapters
-
-from global_chem_extensions.language_adapters.amino_acid_converter.amino_acid_converter import AminoAcidConverter
-
-# Machine Learning
-
-from global_chem_extensions.machine_learning.one_hot_encoding import SmilesOneHotEncoder
-
-# Validation
-
-from global_chem_extensions.validation.partial_smiles import PartialSmilesValidation
-
-# ForceFields
-
-from global_chem_extensions.forcefields.cgenff.cgenff_molecule import CGenFFMolecule
-from global_chem_extensions.forcefields.cgenff.dissimilarity_score import CGenFFDissimilarityScore
-
-from global_chem_extensions.forcefields.gaff2.gaff2_molecule import GaFF2Molecule
-
-# Monitors
-
-from global_chem_extensions.monitoring_services.database_monitor.database_monitor import DatabaseMonitor
-
 class ExtensionsError(Exception):
 
     __version_error_parser__ = "0.0.1"
@@ -90,6 +40,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.analysis_tools.sunburster.sunburster import Sunburster
+
         Sunburster(smiles_list, save_file)
 
 
@@ -123,6 +75,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.analysis_tools.node_pca_analysis.node_pca_analysis import PCAAnalysis
+
         pca_analysis = PCAAnalysis(
             smiles_list,
             morgan_radius,
@@ -155,8 +109,9 @@ class GlobalChemExtensions(object):
 
         '''
 
-        converter = AminoAcidConverter()
+        from global_chem_extensions.language_adapters.amino_acid_converter.amino_acid_converter import AminoAcidConverter
 
+        converter = AminoAcidConverter()
         converted_list = []
 
         for smiles in smiles_list:
@@ -203,6 +158,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.monitoring_services.database_monitor.database_monitor import DatabaseMonitor
+
         database_monitor = DatabaseMonitor()
         database_monitor.heartbeat()
 
@@ -235,6 +192,8 @@ class GlobalChemExtensions(object):
             the filtered data set
         '''
 
+        from global_chem_extensions.analysis_tools.drug_design_filters.drug_design_filters import DrugDesignFilters
+
         drug_design_filters = DrugDesignFilters(
             smiles_list,
             lipinski_rule_of_5=lipinski_rule_of_5,
@@ -261,6 +220,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.software_adapters.networkx_adapter.networkx_adapter import NetworkxAdapter
+
         network_adapter = NetworkxAdapter()
         converted_network = network_adapter.convert(network)
 
@@ -276,6 +237,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.analysis_tools.deep_layer_scatter.deep_layer_scatter import DeepLayerScatter
+
         deep_layer_scatter = DeepLayerScatter(deep_layer_network, save_file=save_file)
         deep_layer_scatter.scatter(height=height, width=None)
 
@@ -288,6 +251,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.analysis_tools.smarts_pattern_identifier.smarts_pattern_identifier import SmartsPatternIdentifier
+
         spi = SmartsPatternIdentifier()
         spi.launch_app(host=host, port=port, debug=debugger)
 
@@ -310,6 +275,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.software_adapters.dimorphite_dl_adapter.dimorphite_dl import DimorphiteAdapter
+
         dimorphite_adapter = DimorphiteAdapter(
             smiles_list,
             min_ph,
@@ -351,6 +318,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.validation.partial_smiles import PartialSmilesValidation
+
         psv = PartialSmilesValidation(
             partial=partial
         )
@@ -390,6 +359,8 @@ class GlobalChemExtensions(object):
             title (String): Title of the PDF
         '''
 
+        from global_chem_extensions.software_adapters.pdf_adapter.molpdf_parser import MolPDFAdapter
+
         molpdf_adapter = MolPDFAdapter(
             smiles = smiles,
             labels = labels,
@@ -415,6 +386,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.software_adapters.pdf_adapter.molpdf_parser import MolPDFAdapter
+
         molpdf_adapter = MolPDFAdapter(
             file_name = file_name
         )
@@ -441,6 +414,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.machine_learning.one_hot_encoding import SmilesOneHotEncoder
+
         encoder = SmilesOneHotEncoder(
             smiles_list = smiles_list,
             max_length = max_length
@@ -466,6 +441,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.machine_learning.one_hot_encoding import SmilesOneHotEncoder
+
         encoder = SmilesOneHotEncoder(
             smiles_list = smiles_list,
         )
@@ -490,6 +467,11 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.entities.molecule.molecule import GlobalChemMolecule
+        from global_chem_extensions.forcefields.cgenff.cgenff_molecule import CGenFFMolecule
+        from global_chem_extensions.forcefields.gaff2.gaff2_molecule import GaFF2Molecule
+
+
         cgenff_molecule = None
         gaff2_molecule = None
 
@@ -523,6 +505,8 @@ class GlobalChemExtensions(object):
             peptide_sequence (String): Peptide sequence
         '''
 
+        from global_chem_extensions.entities.protein.protein import GlobalChemProtein
+
         global_chem_protein = GlobalChemProtein(
             pdb_file = pdb_id,
             fetch_pdb = pdb_path,
@@ -544,6 +528,8 @@ class GlobalChemExtensions(object):
             name (String): Name of the DNA instance
         '''
 
+        from global_chem_extensions.entities.dna.dna import GlobalChemDNA
+
         global_chem_dna = GlobalChemDNA(
             dna_sequence = dna_sequence,
             name = name
@@ -564,6 +550,8 @@ class GlobalChemExtensions(object):
             name (String): Name of the DNA instance
         '''
 
+        from global_chem_extensions.entities.rna.rna import GlobalChemRNA
+
         global_chem_rna = GlobalChemRNA(
             rna_sequence = rna_sequence,
             name = name
@@ -582,6 +570,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.forcefields.cgenff.cgenff_molecule import CGenFFMolecule
+
         cgenff_molecule = CGenFFMolecule(
             stream_file=stream_file
         )
@@ -599,6 +589,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.forcefields.gaff2.gaff2_molecule import GaFF2Molecule
+
         gaff2_molecule = GaFF2Molecule(
             frcmod_file=frcmod_file
         )
@@ -615,6 +607,8 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.software_adapters.smarts_visualizer.smarts_visualizer import SmartsVisualizer
+
         visualizer = SmartsVisualizer(
             smarts
         )
@@ -637,6 +631,9 @@ class GlobalChemExtensions(object):
 
         '''
 
+        from global_chem_extensions.forcefields.cgenff.cgenff_molecule import CGenFFMolecule
+        from global_chem_extensions.forcefields.cgenff.dissimilarity_score import CGenFFDissimilarityScore
+
         molecule_1 = CGenFFMolecule(stream_file_1)
         molecule_2 = CGenFFMolecule(stream_file_2)
 
@@ -649,3 +646,32 @@ class GlobalChemExtensions(object):
         score = dissimilar.compute_dissimilar_score_two_compounds()
 
         return score
+
+    @staticmethod
+    def apply_plotly_template(
+            figure,
+            x_title='X-Axis',
+            y_title = 'Y-Axis',
+            height = 500,
+            width = 1000
+    ):
+        '''
+
+        Arguments:
+            figure (Plotly Figure Object): plotly object you want beautified
+            x_title (String): title of the x-axis
+            y_title (String): title of the y-axis
+            height (Int): height of the graph
+            width (Int): width of the graph
+
+        '''
+
+        from global_chem_extensions.graphing_templates.plotly_template import PlotlyTemplate
+
+        PlotlyTemplate(
+            figure,
+            x_title=x_title,
+            y_title = y_title,
+            height = height,
+            width = width
+        )
\ No newline at end of file
